# Storey

[![CI](https://github.com/mlrun/storey/workflows/CI/badge.svg)](https://github.com/mlrun/storey/actions?query=workflow%3ACI)

Storey is an asynchronous streaming library, for real time event processing and feature extraction. It's a component
of mlrun.

&#x25B6; For more information, see [mlrun documentation](https://docs.mlrun.org/en/stable/), and the page on [storey
transformations](https://docs.mlrun.org/en/latest/api/storey.transformations.html) in particular.
